# -*- coding: UTF-8 -*-
# FlameBot, Python IRC bot modular and extensible
#           Weather observations and forecasts module
#
# Copyright (c) 2005 Diego Pettenò
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# - Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
# - Redistributions in binary form must reproduce the above
#   copyright notice, this list of conditions and the following
#   disclaimer in the documentation and/or other materials provided
#   with the distribution.
# - The name of the author may not be used to endorse or promote
#   products derived from this software without specific prior
#   written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

from string import Template

# Local imports
from flamebot_utils import irc_answer, FlameBotOpener

directions = [ "N", "NNE", "NE", "ENE", "E", "ESE", "SE", "SSE", "S", "SSO", "SO", "OSO", "O", "ONO", "NO", "NNO" ]
taf_answer = Template("$place forecast (valid $start to $end) Wind $Wspeed $Wmeasure dir. $Wdir")

def cmd_forecast(connection, nick, channel, arg):
	url = "ftp://weather.noaa.gov/data/forecasts/taf/stations/" + arg.upper() + ".TXT"
	print "Going to request " + url
	
	rawdata = FlameBotOpener().open(url).read()
	
	toks = []
	date = ""
	for line in rawdata.splitlines():
		if date == "":
			date = line
		else:
			toks += line.split(' ')
	
	print "Retrieved new forecast for " + toks[0] + " at " + date
	
	data = { 'place': toks[0], 'start' : toks[2][2:4], 'end' : toks[2][4:6], 'Wspeed' : toks[3][3:5] }
	
	if toks[3][5:7] == "KT":
		data['Wmeasure'] = "KMH"
	else:
		data['Wmeasure'] = "MPH"
		
	wind_dir = toks[3][0:3]
	if wind_dir == "VRB":
		data['Wdir'] = "variable"
	else:
		data['Wdir'] = directions[int(wind_dir)/20] + " (" + wind_dir + " deg.)"
	
	irc_answer(connection, nick, channel, taf_answer.substitute(data))
	
def register_flamebot(bot):
	bot.addcommand("forecast", cmd_forecast)

def unregister(bot):
	bot.removecommand("forecast")
